@@ -12,11 +12,11 @@ from os import path, listdir
 # PROCEED WITH TESTS
 def main():
     if "testa.json" not in listdir("."):
-        print("[x]Any testa configuration file present !"))
+        print("[x] Any testa configuration file present !")
         exit()
     try:
-        if !path.exists("testa.json"):
-            print("[x]The configuration file doesn't exist !")
+        if not path.exists("testa.json"):
+            print("[x] The configuration file doesn't exist !")
             exit()
 
         with open("testa.json", 'r+') as filee:
@@ -61,12 +61,9 @@ def main():
             testa_test.end()
             # We Print the Report resume:
             print("[+] Reports saved in './" + testa_test.date_report + "'")
-    else:
-        print("[+] Bad parameters input for the path and the config!")
-except Exception:
-    print("[+] Testa just Crashed, verify your JSON file !!!")
-    get_trace()
-
+    except Exception:
+        print("[+] Testa just Crashed, verify your JSON file !!!")
+        get_trace()
 
 
 if __name__== "__main__":
